@@ -97,6 +97,28 @@ Schema:
                     ]
                   }
                 },
+                "videocontrol_descriptors": [
+                  {
+                    "<item>": {
+                      "value":                string,
+                      "description":          string,
+                      "attributes": [
+                                              string
+                      ]
+                    }
+                  }
+                ],
+                "videostreaming_descriptors": [
+                  {
+                    "<item>": {
+                      "value":                string,
+                      "description":          string,
+                      "attributes": [
+                                              string
+                      ]
+                    }
+                  }
+                ],
                 "endpoint_descriptors": [
                   {
                     "<item>": {
@@ -269,12 +291,13 @@ from jc.exceptions import ParseError
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.2'
+    version = '1.3'
     description = '`lsusb` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['lsusb']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -306,6 +329,145 @@ class _NestedDict(dict):
         return self.setdefault(key, _NestedDict())
 
 
+class _root_obj:
+    def __init__(self, name):
+        self.name = name
+        self.list = []
+
+    def _entries_for_this_bus_exist(self, bus_idx):
+        """Returns true if there are object entries for the corresponding bus index"""
+        for item in self.list:
+            keyname = tuple(item.keys())[0]
+
+            if '_state' in item[keyname] and item[keyname]['_state']['bus_idx'] == bus_idx:
+                return True
+
+        return False
+
+    def _update_output(self, bus_idx, output_line):
+        """modifies output_line dictionary for the corresponding bus index.
+        output_line is the self.output_line attribute from the _lsusb object."""
+        for item in self.list:
+            keyname = tuple(item.keys())[0]
+
+            if '_state' in item[keyname] and item[keyname]['_state']['bus_idx'] == bus_idx:
+                # is this a top level value or an attribute?
+                if item[keyname]['_state']['attribute_value']:
+                    last_item = item[keyname]['_state']['last_item']
+                    if 'attributes' not in output_line[f'{self.name}'][last_item]:
+                        output_line[f'{self.name}'][last_item]['attributes'] = []
+
+                    this_attribute = f'{keyname} {item[keyname].get("value", "")} {item[keyname].get("description", "")}'.strip()
+                    output_line[f'{self.name}'][last_item]['attributes'].append(this_attribute)
+                    continue
+
+                output_line[f'{self.name}'].update(item)
+                del output_line[f'{self.name}'][keyname]['_state']
+
+
+class _descriptor_obj:
+    def __init__(self, name):
+        self.name = name
+        self.list = []
+
+    def _entries_for_this_bus_and_interface_idx_exist(self, bus_idx, iface_idx):
+        """Returns true if there are object entries for the corresponding bus index
+        and interface index"""
+        for item in self.list:
+            keyname = tuple(item.keys())[0]
+
+            if '_state' in item[keyname] and item[keyname]['_state']['bus_idx'] == bus_idx \
+                and item[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+
+                return True
+
+        return False
+
+    def _update_output(self, bus_idx, iface_idx, output_line):
+        """modifies output_line dictionary for the corresponding bus index and
+        interface index. output_line is the i_desc_obj object."""
+        for item in self.list:
+            keyname = tuple(item.keys())[0]
+
+            if '_state' in item[keyname] and item[keyname]['_state']['bus_idx'] == bus_idx \
+                and item[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+
+                # is this a top level value or an attribute?
+                if item[keyname]['_state']['attribute_value']:
+                    last_item = item[keyname]['_state']['last_item']
+                    if 'attributes' not in output_line[f'{self.name}'][last_item]:
+                        output_line[f'{self.name}'][last_item]['attributes'] = []
+
+                    this_attribute = f'{keyname} {item[keyname].get("value", "")} {item[keyname].get("description", "")}'.strip()
+                    output_line[f'{self.name}'][last_item]['attributes'].append(this_attribute)
+                    continue
+
+                output_line[f'{self.name}'].update(item)
+                del output_line[f'{self.name}'][keyname]['_state']
+
+
+class _descriptor_list:
+    def __init__(self, name):
+        self.name = name
+        self.list = []
+
+    def _entries_for_this_bus_and_interface_idx_exist(self, bus_idx, iface_idx):
+        """Returns true if there are object entries for the corresponding bus index
+        and interface index"""
+        for item in self.list:
+            keyname = tuple(item.keys())[0]
+
+            if '_state' in item[keyname] and item[keyname]['_state']['bus_idx'] == bus_idx \
+                and item[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+
+                return True
+
+        return False
+
+    def _get_objects_list(self, bus_idx, iface_idx):
+        """Returns a list of descriptor object dictionaries for the corresponding
+        bus index and interface index"""
+        object_collection = []
+
+        # find max number of items in this object that match the bus_idx and iface_idx
+        num_of_items = -1
+        for item in self.list:
+            keyname = tuple(item.keys())[0]
+
+            if '_state' in item[keyname] and item[keyname]['_state']['bus_idx'] == bus_idx \
+                and item[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+
+                num_of_items = item[keyname]['_state'][f'{self.name}_idx']
+
+        # create and return the collection of objects that match the bus_idx and iface_idx
+        if num_of_items > -1:
+            for obj_idx in range(num_of_items + 1):
+                this_object = {}
+                for item in self.list:
+                    keyname = tuple(item.keys())[0]
+
+                    if '_state' in item[keyname] and item[keyname]['_state']['bus_idx'] == bus_idx \
+                        and item[keyname]['_state']['interface_descriptor_idx'] == iface_idx \
+                        and item[keyname]['_state'][f'{self.name}_idx'] == obj_idx:
+
+                        # is this a top level value or an attribute?
+                        if item[keyname]['_state']['attribute_value']:
+                            last_item = item[keyname]['_state']['last_item']
+                            if 'attributes' not in this_object[last_item]:
+                                this_object[last_item]['attributes'] = []
+
+                            this_attribute = f'{keyname} {item[keyname].get("value", "")} {item[keyname].get("description", "")}'.strip()
+                            this_object[last_item]['attributes'].append(this_attribute)
+                            continue
+
+                        this_object.update(item)
+                        del item[keyname]['_state']
+
+                object_collection.append(this_object)
+
+        return object_collection
+
+
 class _LsUsb():
     def __init__(self):
         self.raw_output = []
@@ -313,27 +475,37 @@ class _LsUsb():
 
         self.section = ''
         self.old_section = ''
+
+        # section_header is formatted with the correct spacing to be used with
+        # jc.parsers.universal.sparse_table_parse(). Pad end of string to be at least len of 25
+        # this value changes for different sections (e.g. videocontrol & videostreaming)
+        self.normal_section_header = 'key                   val description'
+        self.larger_section_header = 'key                               val description'
+
         self.bus_idx = -1
         self.interface_descriptor_idx = -1
         self.endpoint_descriptor_idx = -1
+        self.videocontrol_interface_descriptor_idx = -1
+        self.videostreaming_interface_descriptor_idx = -1
         self.last_item = ''
         self.last_indent = 0
         self.attribute_value = False
 
         self.bus_list = []
-        self.device_descriptor_list = []
-        self.configuration_descriptor_list = []
-        self.interface_association_list = []
+        self.device_descriptor = _root_obj('device_descriptor')
+        self.configuration_descriptor = _root_obj('configuration_descriptor')
+        self.interface_association = _root_obj('interface_association')
         self.interface_descriptor_list = []
-        self.interface_descriptor_attribute_list = []
-        self.cdc_header_list = []
-        self.cdc_call_management_list = []
-        self.cdc_acm_list = []
-        self.cdc_union_list = []
-        self.endpoint_descriptor_list = []
-        self.hid_device_descriptor_list = []
-        self.report_descriptors_list = []
-        self.hub_descriptor_list = []
+        self.cdc_header = _descriptor_obj('cdc_header')
+        self.cdc_call_management = _descriptor_obj('cdc_call_management')
+        self.cdc_acm = _descriptor_obj('cdc_acm')
+        self.cdc_union = _descriptor_obj('cdc_union')
+        self.endpoint_descriptors = _descriptor_list('endpoint_descriptor')
+        self.videocontrol_interface_descriptors = _descriptor_list('videocontrol_interface_descriptor')
+        self.videostreaming_interface_descriptors = _descriptor_list('videostreaming_interface_descriptor')
+        self.hid_device_descriptor = _descriptor_obj('hid_device_descriptor')
+        # self.report_descriptors_list = []          # not implemented
+        self.hub_descriptor = _root_obj('hub_descriptor')
         self.hub_port_status_list = []
         self.device_qualifier_list = []
         self.device_status_list = []
@@ -354,14 +526,21 @@ class _LsUsb():
         # determine whether this is a top-level value item or lower-level attribute
         if indent > self.last_indent and self.old_section == self.section:
             self.attribute_value = True
-        elif indent == self.last_indent and self.attribute_value and self.old_section == self.section:
+
+        elif indent == self.last_indent and self.attribute_value \
+            and self.old_section == self.section:
+
             self.attribute_value = True
+
         else:
             self.attribute_value = False
 
-        # section_header is formatted with the correct spacing to be used with
-        # jc.parsers.universal.sparse_table_parse(). Pad end of string to be at least len of 25
-        section_header = 'key                   val description'
+        section_header = self.normal_section_header
+
+        if self.section == 'videocontrol_interface_descriptor' \
+            or self.section == 'videostreaming_interface_descriptor':
+
+            section_header = self.larger_section_header
 
         temp_obj = [section_header, line.strip() + (' ' * 25)]
         temp_obj = sparse_table_parse(temp_obj)
@@ -376,7 +555,9 @@ class _LsUsb():
                     'last_item': self.last_item,
                     'bus_idx': self.bus_idx,
                     'interface_descriptor_idx': self.interface_descriptor_idx,
-                    'endpoint_descriptor_idx': self.endpoint_descriptor_idx
+                    'endpoint_descriptor_idx': self.endpoint_descriptor_idx,
+                    'videocontrol_interface_descriptor_idx': self.videocontrol_interface_descriptor_idx,
+                    'videostreaming_interface_descriptor_idx': self.videostreaming_interface_descriptor_idx
                 }
             }
         }
@@ -428,12 +609,15 @@ class _LsUsb():
             self.attribute_value = False
             return True
 
-        # bus information is on the same line so need to extract data immediately and set indexes
+        # bus information is on the same line so need to extract data
+        # immediately and set indexes
         if line.startswith('Bus '):
             self.section = 'bus'
             self.bus_idx += 1
             self.interface_descriptor_idx = -1
             self.endpoint_descriptor_idx = -1
+            self.videocontrol_interface_descriptor_idx = -1
+            self.videostreaming_interface_descriptor_idx = -1
             self.attribute_value = False
             line_split = line.strip().split(maxsplit=6)
             self.bus_list.append(
@@ -441,7 +625,8 @@ class _LsUsb():
                     'bus': line_split[1],
                     'device': line_split[3][:-1],
                     'id': line_split[5],
-                    'description': (line_split[6:7] or [None])[0],     # way to get a list item or None
+                    # way to get a list item or None
+                    'description': (line_split[6:7] or [None])[0],
                     '_state': {
                         'bus_idx': self.bus_idx
                     }
@@ -449,22 +634,36 @@ class _LsUsb():
             )
             return True
 
-        # This section is a list, so need to update indexes
+        # These sections are lists, so need to update indexes
         if line.startswith('    Interface Descriptor:'):
             self.section = 'interface_descriptor'
             self.interface_descriptor_idx += 1
             self.endpoint_descriptor_idx = -1
+            self.videocontrol_interface_descriptor_idx = -1
+            self.videostreaming_interface_descriptor_idx = -1
             self.attribute_value = False
             return True
 
-        # This section is a list, so need to update the index
         if line.startswith('      Endpoint Descriptor:'):
             self.section = 'endpoint_descriptor'
             self.endpoint_descriptor_idx += 1
             self.attribute_value = False
             return True
 
-        # some device status information is displayed on the initial line so need to extract immediately
+        if line.startswith('      VideoControl Interface Descriptor:'):
+            self.section = 'videocontrol_interface_descriptor'
+            self.videocontrol_interface_descriptor_idx += 1
+            self.attribute_value = False
+            return True
+
+        if line.startswith('      VideoStreaming Interface Descriptor:'):
+            self.section = 'videostreaming_interface_descriptor'
+            self.videostreaming_interface_descriptor_idx += 1
+            self.attribute_value = False
+            return True
+
+        # some device status information is displayed on the initial line so
+        # need to extract immediately
         if line.startswith('Device Status:'):
             self.section = 'device_status'
             self.attribute_value = False
@@ -506,18 +705,20 @@ class _LsUsb():
 
     def _populate_lists(self, line):
         section_list_map = {
-            'device_descriptor': self.device_descriptor_list,
-            'configuration_descriptor': self.configuration_descriptor_list,
-            'interface_association': self.interface_association_list,
+            'device_descriptor': self.device_descriptor.list,
+            'configuration_descriptor': self.configuration_descriptor.list,
+            'interface_association': self.interface_association.list,
             'interface_descriptor': self.interface_descriptor_list,
-            'cdc_header': self.cdc_header_list,
-            'cdc_call_management': self.cdc_call_management_list,
-            'cdc_acm': self.cdc_acm_list,
-            'cdc_union': self.cdc_union_list,
-            'hid_device_descriptor': self.hid_device_descriptor_list,
-            'report_descriptors': self.report_descriptors_list,
-            'endpoint_descriptor': self.endpoint_descriptor_list,
-            'hub_descriptor': self.hub_descriptor_list,
+            'cdc_header': self.cdc_header.list,
+            'cdc_call_management': self.cdc_call_management.list,
+            'cdc_acm': self.cdc_acm.list,
+            'cdc_union': self.cdc_union.list,
+            'hid_device_descriptor': self.hid_device_descriptor.list,
+            # 'report_descriptors': self.report_descriptors_list,         # not implemented
+            'videocontrol_interface_descriptor': self.videocontrol_interface_descriptors.list,
+            'videostreaming_interface_descriptor': self.videostreaming_interface_descriptors.list,
+            'endpoint_descriptor': self.endpoint_descriptors.list,
+            'hub_descriptor': self.hub_descriptor.list,
             'device_qualifier': self.device_qualifier_list
         }
 
@@ -527,7 +728,9 @@ class _LsUsb():
                 return True
 
         # special handling of these sections
-        if line.startswith(' ') and self.section == 'hub_port_status':
+        if line.startswith(' ') and not line.startswith('     ') \
+            and self.section == 'hub_port_status':
+
             self.hub_port_status_list.append(self._add_hub_port_status_attributes(line))
             return True
 
@@ -546,6 +749,10 @@ class _LsUsb():
         ['device_descriptor']['configuration_descriptor']['interface_association'] = {}
         ['device_descriptor']['configuration_descriptor']['interface_descriptors'] = []
         ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0] = {}
+        ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0]['videocontrol_interface_descriptors'] = []
+        ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0]['videocontrol_interface_descriptors'][0] = {}
+        ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0]['videostreaming_interface_descriptors'] = []
+        ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0]['videostreaming_interface_descriptors'][0] = {}
         ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0]['cdc_header'] = {}
         ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0]['cdc_call_management'] = {}
         ['device_descriptor']['configuration_descriptor']['interface_descriptors'][0]['cdc_acm'] = {}
@@ -567,81 +774,56 @@ class _LsUsb():
             del item['_state']
             self.output_line.update(item)
 
-            for dd in self.device_descriptor_list:
-                keyname = tuple(dd.keys())[0]
-                if '_state' in dd[keyname] and dd[keyname]['_state']['bus_idx'] == idx:
+            # add initial root-level keys
+            if self.device_descriptor._entries_for_this_bus_exist(idx):
+                self.device_descriptor._update_output(idx, self.output_line)
 
-                    # is this a top level value or an attribute?
-                    if dd[keyname]['_state']['attribute_value']:
-                        last_item = dd[keyname]['_state']['last_item']
-                        if 'attributes' not in self.output_line['device_descriptor'][last_item]:
-                            self.output_line['device_descriptor'][last_item]['attributes'] = []
+            if self.configuration_descriptor._entries_for_this_bus_exist(idx):
+                self.configuration_descriptor._update_output(
+                    idx, self.output_line['device_descriptor']
+                )
 
-                        this_attribute = f'{keyname} {dd[keyname].get("value", "")} {dd[keyname].get("description", "")}'.strip()
-                        self.output_line['device_descriptor'][last_item]['attributes'].append(this_attribute)
-                        continue
+            if self.interface_association._entries_for_this_bus_exist(idx):
+                self.interface_association._update_output(
+                    idx, self.output_line['device_descriptor']['configuration_descriptor']
+                )
 
-                    self.output_line['device_descriptor'].update(dd)
-                    del self.output_line['device_descriptor'][keyname]['_state']
-
-            for cd in self.configuration_descriptor_list:
-                keyname = tuple(cd.keys())[0]
-                if '_state' in cd[keyname] and cd[keyname]['_state']['bus_idx'] == idx:
-
-                    # is this a top level value or an attribute?
-                    if cd[keyname]['_state']['attribute_value']:
-                        last_item = cd[keyname]['_state']['last_item']
-                        if 'attributes' not in self.output_line['device_descriptor']['configuration_descriptor'][last_item]:
-                            self.output_line['device_descriptor']['configuration_descriptor'][last_item]['attributes'] = []
-
-                        this_attribute = f'{keyname} {cd[keyname].get("value", "")} {cd[keyname].get("description", "")}'.strip()
-                        self.output_line['device_descriptor']['configuration_descriptor'][last_item]['attributes'].append(this_attribute)
-                        continue
-
-                    self.output_line['device_descriptor']['configuration_descriptor'].update(cd)
-                    del self.output_line['device_descriptor']['configuration_descriptor'][keyname]['_state']
-
-            for ia in self.interface_association_list:
-                keyname = tuple(ia.keys())[0]
-                if '_state' in ia[keyname] and ia[keyname]['_state']['bus_idx'] == idx:
-
-                    # is this a top level value or an attribute?
-                    if ia[keyname]['_state']['attribute_value']:
-                        last_item = ia[keyname]['_state']['last_item']
-                        if 'attributes' not in self.output_line['device_descriptor']['configuration_descriptor']['interface_association'][last_item]:
-                            self.output_line['device_descriptor']['configuration_descriptor']['interface_association'][last_item]['attributes'] = []
-
-                        this_attribute = f'{keyname} {ia[keyname].get("value", "")} {ia[keyname].get("description", "")}'.strip()
-                        self.output_line['device_descriptor']['configuration_descriptor']['interface_association'][last_item]['attributes'].append(this_attribute)
-                        continue
-
-                    self.output_line['device_descriptor']['configuration_descriptor']['interface_association'].update(ia)
-                    del self.output_line['device_descriptor']['configuration_descriptor']['interface_association'][keyname]['_state']
-
-            # add interface_descriptor key if it doesn't exist and there are entries for this bus
+            # add interface_descriptor key if it doesn't exist and there
+            # are entries for this bus
             for iface_attrs in self.interface_descriptor_list:
                 keyname = tuple(iface_attrs.keys())[0]
-                if '_state' in iface_attrs[keyname] and iface_attrs[keyname]['_state']['bus_idx'] == idx:
+
+                if '_state' in iface_attrs[keyname] \
+                    and iface_attrs[keyname]['_state']['bus_idx'] == idx:
+
                     self.output_line['device_descriptor']['configuration_descriptor']['interface_descriptors'] = []
 
             # find max index for this bus idx, then iterate over that range
             i_desc_iters = -1
             for iface_attrs in self.interface_descriptor_list:
                 keyname = tuple(iface_attrs.keys())[0]
-                if '_state' in iface_attrs[keyname] and iface_attrs[keyname]['_state']['bus_idx'] == idx:
+
+                if '_state' in iface_attrs[keyname] \
+                    and iface_attrs[keyname]['_state']['bus_idx'] == idx:
+
                     i_desc_iters = iface_attrs[keyname]['_state']['interface_descriptor_idx']
 
             # create the interface descriptor object
             if i_desc_iters > -1:
                 for iface_idx in range(i_desc_iters + 1):
                     i_desc_obj = _NestedDict()
+
                     for iface_attrs in self.interface_descriptor_list:
                         keyname = tuple(iface_attrs.keys())[0]
-                        if '_state' in iface_attrs[keyname] and iface_attrs[keyname]['_state']['bus_idx'] == idx and iface_attrs[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+
+                        if '_state' in iface_attrs[keyname] \
+                            and iface_attrs[keyname]['_state']['bus_idx'] == idx \
+                            and iface_attrs[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
 
                             # is this a top level value or an attribute?
                             if iface_attrs[keyname]['_state']['attribute_value']:
                                 last_item = iface_attrs[keyname]['_state']['last_item']
+
                                 if 'attributes' not in i_desc_obj[last_item]:
                                     i_desc_obj[last_item]['attributes'] = []
 
@@ -652,168 +834,70 @@ class _LsUsb():
                             del iface_attrs[keyname]['_state']
                             i_desc_obj.update(iface_attrs)
 
-                    # add other nodes to the object (cdc_header, endpoint descriptors, etc.)
-                    for ch in self.cdc_header_list:
-                        keyname = tuple(ch.keys())[0]
-                        if '_state' in ch[keyname] and ch[keyname]['_state']['bus_idx'] == idx and ch[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+                    # add the rest of the interface descriptor keys to the object
+                    if self.cdc_header._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        self.cdc_header._update_output(idx, iface_idx, i_desc_obj)
 
-                            # is this a top level value or an attribute?
-                            if ch[keyname]['_state']['attribute_value']:
-                                last_item = ch[keyname]['_state']['last_item']
-                                if 'attributes' not in i_desc_obj['cdc_header'][last_item]:
-                                    i_desc_obj['cdc_header'][last_item]['attributes'] = []
+                    if self.cdc_call_management._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        self.cdc_call_management._update_output(idx, iface_idx, i_desc_obj)
 
-                                this_attribute = f'{keyname} {ch[keyname].get("value", "")} {ch[keyname].get("description", "")}'.strip()
-                                i_desc_obj['cdc_header'][last_item]['attributes'].append(this_attribute)
-                                continue
+                    if self.cdc_acm._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        self.cdc_acm._update_output(idx, iface_idx, i_desc_obj)
 
-                            i_desc_obj['cdc_header'].update(ch)
-                            del i_desc_obj['cdc_header'][keyname]['_state']
+                    if self.cdc_union._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        self.cdc_union._update_output(idx, iface_idx, i_desc_obj)
 
-                    for ccm in self.cdc_call_management_list:
-                        keyname = tuple(ccm.keys())[0]
-                        if '_state' in ccm[keyname] and ccm[keyname]['_state']['bus_idx'] == idx and ccm[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+                    if self.hid_device_descriptor._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        self.hid_device_descriptor._update_output(idx, iface_idx, i_desc_obj)
 
-                            # is this a top level value or an attribute?
-                            if ccm[keyname]['_state']['attribute_value']:
-                                last_item = ccm[keyname]['_state']['last_item']
-                                if 'attributes' not in i_desc_obj['cdc_call_management'][last_item]:
-                                    i_desc_obj['cdc_call_management'][last_item]['attributes'] = []
+                    # Not Implemented: Report Descriptors (need more samples)
+                    # for rd in self.report_descriptors_list:
+                    #     keyname = tuple(rd.keys())[0]
+                    #     if '_state' in rd[keyname] and rd[keyname]['_state']['bus_idx'] == idx and rd[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
+                    #         i_desc_obj['hid_device_descriptor']['report_descriptors'].update(rd)
+                    #         del i_desc_obj['hid_device_descriptor']['report_descriptors'][keyname]['_state']
 
-                                this_attribute = f'{keyname} {ccm[keyname].get("value", "")} {ccm[keyname].get("description", "")}'.strip()
-                                i_desc_obj['cdc_call_management'][last_item]['attributes'].append(this_attribute)
-                                continue
+                    if self.videocontrol_interface_descriptors._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        i_desc_obj['videocontrol_interface_descriptors'] = []
+                        i_desc_obj['videocontrol_interface_descriptors'].extend(
+                            self.videocontrol_interface_descriptors._get_objects_list(idx, iface_idx)
+                        )
 
-                            i_desc_obj['cdc_call_management'].update(ccm)
-                            del i_desc_obj['cdc_call_management'][keyname]['_state']
+                    if self.videostreaming_interface_descriptors._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        i_desc_obj['videostreaming_interface_descriptors'] = []
+                        i_desc_obj['videostreaming_interface_descriptors'].extend(
+                            self.videostreaming_interface_descriptors._get_objects_list(idx, iface_idx)
+                        )
 
-                    for ca in self.cdc_acm_list:
-                        keyname = tuple(ca.keys())[0]
-                        if '_state' in ca[keyname] and ca[keyname]['_state']['bus_idx'] == idx and ca[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
-
-                            # is this a top level value or an attribute?
-                            if ca[keyname]['_state']['attribute_value']:
-                                last_item = ca[keyname]['_state']['last_item']
-                                if 'attributes' not in i_desc_obj['cdc_acm'][last_item]:
-                                    i_desc_obj['cdc_acm'][last_item]['attributes'] = []
-
-                                this_attribute = f'{keyname} {ca[keyname].get("value", "")} {ca[keyname].get("description", "")}'.strip()
-                                i_desc_obj['cdc_acm'][last_item]['attributes'].append(this_attribute)
-                                continue
-
-                            i_desc_obj['cdc_acm'].update(ca)
-                            del i_desc_obj['cdc_acm'][keyname]['_state']
-
-                    for cu in self.cdc_union_list:
-                        keyname = tuple(cu.keys())[0]
-                        if '_state' in cu[keyname] and cu[keyname]['_state']['bus_idx'] == idx and cu[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
-
-                            # is this a top level value or an attribute?
-                            if cu[keyname]['_state']['attribute_value']:
-                                last_item = cu[keyname]['_state']['last_item']
-                                if 'attributes' not in i_desc_obj['cdc_union'][last_item]:
-                                    i_desc_obj['cdc_union'][last_item]['attributes'] = []
-
-                                this_attribute = f'{keyname} {cu[keyname].get("value", "")} {cu[keyname].get("description", "")}'.strip()
-                                i_desc_obj['cdc_union'][last_item]['attributes'].append(this_attribute)
-                                continue
-
-                            i_desc_obj['cdc_union'].update(cu)
-                            del i_desc_obj['cdc_union'][keyname]['_state']
-
-                    for hidd in self.hid_device_descriptor_list:
-                        keyname = tuple(hidd.keys())[0]
-                        if '_state' in hidd[keyname] and hidd[keyname]['_state']['bus_idx'] == idx and hidd[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
-
-                            # is this a top level value or an attribute?
-                            if hidd[keyname]['_state']['attribute_value']:
-                                last_item = hidd[keyname]['_state']['last_item']
-                                if 'attributes' not in i_desc_obj['hid_device_descriptor'][last_item]:
-                                    i_desc_obj['hid_device_descriptor'][last_item]['attributes'] = []
-
-                                this_attribute = f'{keyname} {hidd[keyname].get("value", "")} {hidd[keyname].get("description", "")}'.strip()
-                                i_desc_obj['hid_device_descriptor'][last_item]['attributes'].append(this_attribute)
-                                continue
-
-                            i_desc_obj['hid_device_descriptor'].update(hidd)
-                            del i_desc_obj['hid_device_descriptor'][keyname]['_state']
-
-                        # Not Implemented: Report Descriptors (need more samples)
-                        # for rd in self.report_descriptors_list:
-                        #     keyname = tuple(rd.keys())[0]
-                        #     if '_state' in rd[keyname] and rd[keyname]['_state']['bus_idx'] == idx and rd[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
-                        #         i_desc_obj['hid_device_descriptor']['report_descriptors'].update(rd)
-                        #         del i_desc_obj['hid_device_descriptor']['report_descriptors'][keyname]['_state']
-
-                    # add endpoint_descriptor key if it doesn't exist and there are entries for this interface_descriptor
-                    for endpoint_attrs in self.endpoint_descriptor_list:
-                        keyname = tuple(endpoint_attrs.keys())[0]
-                        if '_state' in endpoint_attrs[keyname] and endpoint_attrs[keyname]['_state']['bus_idx'] == idx and endpoint_attrs[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
-                            i_desc_obj['endpoint_descriptors'] = []
-
-                    # find max index for this endpoint_descriptor idx, then iterate over that range
-                    e_desc_iters = -1
-                    for endpoint_attrs in self.endpoint_descriptor_list:
-                        keyname = tuple(endpoint_attrs.keys())[0]
-                        if '_state' in endpoint_attrs[keyname] and endpoint_attrs[keyname]['_state']['bus_idx'] == idx and endpoint_attrs[keyname]['_state']['interface_descriptor_idx'] == iface_idx:
-                            e_desc_iters = endpoint_attrs[keyname]['_state']['endpoint_descriptor_idx']
-
-                    # create the endpoint descriptor object
-                    if e_desc_iters > -1:
-                        for endpoint_idx in range(e_desc_iters + 1):
-                            e_desc_obj = {}
-                            for endpoint_attrs in self.endpoint_descriptor_list:
-                                keyname = tuple(endpoint_attrs.keys())[0]
-                                if '_state' in endpoint_attrs[keyname] and endpoint_attrs[keyname]['_state']['bus_idx'] == idx and endpoint_attrs[keyname]['_state']['interface_descriptor_idx'] == iface_idx and endpoint_attrs[keyname]['_state']['endpoint_descriptor_idx'] == endpoint_idx:
-
-                                    # is this a top level value or an attribute?
-                                    if endpoint_attrs[keyname]['_state']['attribute_value']:
-                                        last_item = endpoint_attrs[keyname]['_state']['last_item']
-                                        if 'attributes' not in e_desc_obj[last_item]:
-                                            e_desc_obj[last_item]['attributes'] = []
-
-                                        this_attribute = f'{keyname} {endpoint_attrs[keyname].get("value", "")} {endpoint_attrs[keyname].get("description", "")}'.strip()
-                                        e_desc_obj[last_item]['attributes'].append(this_attribute)
-                                        continue
-
-                                    e_desc_obj.update(endpoint_attrs)
-                                    del endpoint_attrs[keyname]['_state']
-
-                            i_desc_obj['endpoint_descriptors'].append(e_desc_obj)
+                    if self.endpoint_descriptors._entries_for_this_bus_and_interface_idx_exist(idx, iface_idx):
+                        i_desc_obj['endpoint_descriptors'] = []
+                        i_desc_obj['endpoint_descriptors'].extend(
+                            self.endpoint_descriptors._get_objects_list(idx, iface_idx)
+                        )
 
                     # add the object to the list of interface descriptors
                     self.output_line['device_descriptor']['configuration_descriptor']['interface_descriptors'].append(i_desc_obj)
 
-            for hd in self.hub_descriptor_list:
-                keyname = tuple(hd.keys())[0]
-                if '_state' in hd[keyname] and hd[keyname]['_state']['bus_idx'] == idx:
-
-                    # is this a top level value or an attribute?
-                    if hd[keyname]['_state']['attribute_value']:
-                        last_item = hd[keyname]['_state']['last_item']
-                        if 'attributes' not in self.output_line['hub_descriptor'][last_item]:
-                            self.output_line['hub_descriptor'][last_item]['attributes'] = []
-
-                        this_attribute = f'{keyname} {hd[keyname].get("value", "")} {hd[keyname].get("description", "")}'.strip()
-                        self.output_line['hub_descriptor'][last_item]['attributes'].append(this_attribute)
-                        continue
-
-                    self.output_line['hub_descriptor'].update(hd)
-                    del self.output_line['hub_descriptor'][keyname]['_state']
+            # add final root-level keys
+            if self.hub_descriptor._entries_for_this_bus_exist(idx):
+                self.hub_descriptor._update_output(idx, self.output_line)
 
             for hps in self.hub_port_status_list:
                 keyname = tuple(hps.keys())[0]
+
                 if '_state' in hps[keyname] and hps[keyname]['_state']['bus_idx'] == idx:
                     self.output_line['hub_descriptor']['hub_port_status'].update(hps)
                     del self.output_line['hub_descriptor']['hub_port_status'][keyname]['_state']
 
             for dq in self.device_qualifier_list:
                 keyname = tuple(dq.keys())[0]
+
                 if '_state' in dq[keyname] and dq[keyname]['_state']['bus_idx'] == idx:
                     self.output_line['device_qualifier'].update(dq)
                     del self.output_line['device_qualifier'][keyname]['_state']
 
             for ds in self.device_status_list:
+
                 if '_state' in ds and ds['_state']['bus_idx'] == idx:
                     self.output_line['device_status'].update(ds)
                     del self.output_line['device_status']['_state']
