@@ -9,7 +9,7 @@ Usage (cli):
 
     $ ping -c 3 1.2.3.4 | jc --ping
 
-    or
+or
 
     $ jc ping -c 3 1.2.3.4
 
@@ -164,12 +164,13 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.7'
+    version = '1.8'
     description = '`ping` and `ping6` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'freebsd']
     magic_commands = ['ping', 'ping6']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -187,14 +188,15 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    int_list = [
+    int_list = {
         'data_bytes', 'packets_transmitted', 'packets_received', 'bytes', 'icmp_seq', 'ttl',
         'duplicates', 'vr', 'hl', 'tos', 'len', 'id', 'flg', 'off', 'pro', 'cks'
-    ]
-    float_list = [
+    }
+
+    float_list = {
         'packet_loss_percent', 'round_trip_ms_min', 'round_trip_ms_avg', 'round_trip_ms_max',
         'round_trip_ms_stddev', 'timestamp', 'time_ms'
-    ]
+    }
 
     for key in proc_data:
         if key in int_list:
@@ -208,6 +210,7 @@ def _process(proc_data):
                 for k in entry:
                     if k in int_list:
                         entry[k] = jc.utils.convert_to_int(entry[k])
+
                     if k in float_list:
                         entry[k] = jc.utils.convert_to_float(entry[k])
 
