@@ -5,7 +5,7 @@ Usage (cli):
 
     $ systemctl list-unit-files | jc --systemctl-luf
 
-    or
+or
 
     $ jc systemctl list-unit-files
 
@@ -14,11 +14,6 @@ Usage (module):
     import jc
     result = jc.parse('systemctl_luf', systemctl_luf_command_output)
 
-    or
-
-    import jc.parsers.systemctl_luf
-    result = jc.parsers.systemctl_luf.parse(systemctl_luf_command_output)
-
 Schema:
 
     [
@@ -58,6 +53,7 @@ class info():
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['systemctl list-unit-files']
+    tags = ['command']
 
 
 __version__ = info.version
