@@ -4,7 +4,7 @@ Usage (cli):
 
     $ ufw status | jc --ufw
 
-    or
+or
 
     $ jc ufw status
 
@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('ufw', ufw_command_output)
 
-    or
-
-    import jc.parsers.ufw
-    result = jc.parsers.ufw.parse(ufw_command_output)
-
 Schema:
 
     {
@@ -207,12 +202,13 @@ import ipaddress
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.1'
+    version = '1.2'
     description = '`ufw status` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['ufw status']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -230,7 +226,7 @@ def _process(proc_data):
 
         Dictionary. Structured to conform to the schema.
     """
-    int_list = ['index', 'to_ip_prefix', 'from_ip_prefix']
+    int_list = {'index', 'to_ip_prefix', 'from_ip_prefix'}
 
     if 'rules' in proc_data:
         for i, item in enumerate(proc_data['rules']):
