@@ -9,7 +9,7 @@ Usage (cli):
 
     $ who | jc --who
 
-    or
+or
 
     $ jc who
 
@@ -136,12 +136,13 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.6'
+    version = '1.7'
     description = '`who` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
     magic_commands = ['who']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -159,8 +160,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'pid'}
+
     for entry in proc_data:
-        int_list = ['pid']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
