@@ -4,7 +4,7 @@ Usage (cli):
 
     $ xrandr | jc --xrandr
 
-    or
+or
 
     $ jc xrandr
 
@@ -141,15 +141,13 @@ import jc.utils
 
 class info:
     """Provides parser metadata (version, author, etc.)"""
-
     version = "1.1"
     description = "`xrandr` command parser"
     author = "Kevin Lyter"
     author_email = "lyter_git at sent.com"
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ["linux", "darwin", "cygwin", "aix", "freebsd"]
     magic_commands = ["xrandr"]
+    tags = ['command']
 
 
 __version__ = info.version
@@ -219,9 +217,9 @@ except ImportError:
 
 _screen_pattern = (
     r"Screen (?P<screen_number>\d+): "
-    + "minimum (?P<minimum_width>\d+) x (?P<minimum_height>\d+), "
-    + "current (?P<current_width>\d+) x (?P<current_height>\d+), "
-    + "maximum (?P<maximum_width>\d+) x (?P<maximum_height>\d+)"
+    + r"minimum (?P<minimum_width>\d+) x (?P<minimum_height>\d+), "
+    + r"current (?P<current_width>\d+) x (?P<current_height>\d+), "
+    + r"maximum (?P<maximum_width>\d+) x (?P<maximum_height>\d+)"
 )
 
 
@@ -250,13 +248,13 @@ def _parse_screen(next_lines: List[str]) -> Optional[Screen]:
 # regex101 demo link
 _device_pattern = (
     r"(?P<device_name>.+) "
-    + "(?P<is_connected>(connected|disconnected)) ?"
-    + "(?P<is_primary> primary)? ?"
-    + "((?P<resolution_width>\d+)x(?P<resolution_height>\d+)"
-    + "\+(?P<offset_width>\d+)\+(?P<offset_height>\d+))? "
-    + "(?P<rotation>(inverted|left|right))? ?"
-    + "\(normal left inverted right x axis y axis\)"
-    + "( ((?P<dimension_width>\d+)mm x (?P<dimension_height>\d+)mm)?)?"
+    + r"(?P<is_connected>(connected|disconnected)) ?"
+    + r"(?P<is_primary> primary)? ?"
+    + r"((?P<resolution_width>\d+)x(?P<resolution_height>\d+)"
+    + r"\+(?P<offset_width>\d+)\+(?P<offset_height>\d+))? "
+    + r"(?P<rotation>(inverted|left|right))? ?"
+    + r"\(normal left inverted right x axis y axis\)"
+    + r"( ((?P<dimension_width>\d+)mm x (?P<dimension_height>\d+)mm)?)?"
 )
 
 
