@@ -6,7 +6,7 @@ Usage (cli):
 
     $ zipinfo <archive> | jc --zipinfo
 
-    or
+or
 
     $ jc zipinfo
 
@@ -77,12 +77,13 @@ import jc.parsers.universal
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.2'
     description = '`zipinfo` command parser'
     author = 'Matt J'
     author_email = 'https://github.com/listuser'
     compatible = ['linux', 'darwin']
     magic_commands = ['zipinfo']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -100,14 +101,16 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'bytes_compressed', 'bytes_uncompressed', 'number_entries',
+                'number_files', 'size', 'filesize'}
+
+    float_list = {'percent_compressed'}
 
     for entry in proc_data:
-        int_list = ['bytes_compressed', 'bytes_uncompressed', 'number_entries',
-                    'number_files', 'size', 'filesize']
-        float_list = ['percent_compressed']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
+
             if key in float_list:
                 entry[key] = jc.utils.convert_to_float(entry[key])
 
@@ -167,7 +170,8 @@ def parse(data, raw=False, quiet=False):
             # 1st line
             # Archive:  log4j-core-2.16.0.jar
             line = archive_item.pop(0)
-            _, archive = line.split()
+            # remove prefix but don't split on spaces for files/paths with spaces
+            archive = line.replace('Archive:  ', '', 1)
 
             # 2nd line
             # Zip file size: 1789565 bytes, number of entries: 1218
