@@ -6,7 +6,8 @@ import shutil
 from datetime import datetime, timezone
 from textwrap import TextWrapper
 from functools import lru_cache
-from typing import List, Iterable, Union, Optional
+from typing import Any, List, Dict, Iterable, Union, Optional, TextIO
+from .jc_types import TimeStampFormatType
 
 
 def _asciify(string: str) -> str:
@@ -21,7 +22,13 @@ def _asciify(string: str) -> str:
     return string
 
 
-def _safe_print(string: str, sep=' ', end='\n', file=sys.stdout, flush=False) -> None:
+def _safe_print(
+    string: str,
+    sep: str = ' ',
+    end: str = '\n',
+    file: TextIO = sys.stdout,
+    flush: bool = False
+) -> None:
     """Output for both UTF-8 and ASCII encoding systems"""
     try:
         print(string, sep=sep, end=end, file=file, flush=flush)
@@ -106,7 +113,7 @@ def error_message(message_lines: List[str]) -> None:
         _safe_print(message, file=sys.stderr)
 
 
-def is_compatible(compatible: List) -> bool:
+def is_compatible(compatible: List[str]) -> bool:
     """
     Returns True if the parser is compatible with the running OS platform.
     """
@@ -120,7 +127,7 @@ def is_compatible(compatible: List) -> bool:
     return platform_found
 
 
-def compatibility(mod_name: str, compatible: List, quiet: bool = False) -> None:
+def compatibility(mod_name: str, compatible: List[str], quiet: bool = False) -> None:
     """
     Checks for the parser's compatibility with the running OS platform and
     prints a warning message to `STDERR` if not compatible and
@@ -134,7 +141,7 @@ def compatibility(mod_name: str, compatible: List, quiet: bool = False) -> None:
                       the parser. compatible options:
                       linux, darwin, cygwin, win32, aix, freebsd
 
-        quiet:        (bool) supress compatibility message if True
+        quiet:        (bool) suppress compatibility message if True
 
     Returns:
 
@@ -172,7 +179,7 @@ def has_data(data: Union[str, bytes]) -> bool:
     return bool(data)
 
 
-def convert_to_int(value: Union[str, float]) -> Optional[int]:
+def convert_to_int(value: object) -> Optional[int]:
     """
     Converts string and float input to int. Strips all non-numeric
     characters from strings.
@@ -202,7 +209,7 @@ def convert_to_int(value: Union[str, float]) -> Optional[int]:
         return None
 
 
-def convert_to_float(value: Union[str, int]) -> Optional[float]:
+def convert_to_float(value: object) -> Optional[float]:
     """
     Converts string and int input to float. Strips all non-numeric
     characters from strings.
@@ -228,7 +235,7 @@ def convert_to_float(value: Union[str, int]) -> Optional[float]:
         return None
 
 
-def convert_to_bool(value: Union[str, int, float]) -> bool:
+def convert_to_bool(value: object) -> bool:
     """
     Converts string, integer, or float input to boolean by checking
     for 'truthy' values.
@@ -266,16 +273,18 @@ def convert_to_bool(value: Union[str, int, float]) -> bool:
     return False
 
 
-def input_type_check(data: str) -> None:
+def input_type_check(data: object) -> None:
     """Ensure input data is a string. Raises `TypeError` if not."""
     if not isinstance(data, str):
         raise TypeError("Input data must be a 'str' object.")
 
 
 class timestamp:
+    __slots__ = ('string', 'format', 'naive', 'utc', 'iso')
+
     def __init__(self,
-                 datetime_string: str,
-                 format_hint: Optional[Iterable] = None
+                 datetime_string: Optional[str],
+                 format_hint: Optional[Iterable[int]] = None
     ) -> None:
         """
         Input a datetime text string of several formats and convert to a
@@ -305,6 +314,9 @@ class timestamp:
 
             utc  (int | None):  aware timestamp only if UTC timezone
                 detected in datetime string. None if conversion fails.
+
+            iso (str | None):  ISO string - timezone information is output
+                only if UTC timezone is detected in the datetime string.
         """
         self.string = datetime_string
 
@@ -317,13 +329,17 @@ class timestamp:
         self.format = dt['format']
         self.naive = dt['timestamp_naive']
         self.utc = dt['timestamp_utc']
+        self.iso = dt['iso']
 
-    def __repr__(self):
-        return f'timestamp(string={self.string!r}, format={self.format}, naive={self.naive}, utc={self.utc})'
+    def __repr__(self) -> str:
+        return f'timestamp(string={self.string!r}, format={self.format}, naive={self.naive}, utc={self.utc}, iso={self.iso!r})'
 
     @staticmethod
-    @lru_cache(maxsize=512)
-    def _parse_dt(dt_string, format_hint=None):
+    @lru_cache(maxsize=2048)
+    def _parse_dt(
+        dt_string: Optional[str],
+        format_hint: Optional[Iterable[int]] = None
+    ) -> Dict[str, Any]:
         """
         Input a datetime text string of several formats and convert to
         a naive or timezone-aware epoch timestamp in UTC.
@@ -354,6 +370,9 @@ class timestamp:
                     # aware timestamp only if UTC timezone detected.
                     # None if conversion fails.
                     "timestamp_utc":        int
+
+                    # ISO string. None if conversion fails.
+                    "iso":                  str
                 }
 
                 The `format` integer denotes which date_time format
@@ -368,9 +387,12 @@ class timestamp:
                 timezone is not found in the date-time string), then this
                 field will be None.
 
+                The `iso` string will only have timezone information if the
+                UTC timezone is detected in `dt_string`.
+
                 If the conversion completely fails, all fields will be None.
         """
-        formats = (
+        formats: tuple[TimeStampFormatType, ...] = (
             {'id': 1000, 'format': '%a %b %d %H:%M:%S %Y', 'locale': None},  # manual C locale format conversion: Tue Mar 23 16:12:11 2021 or Tue Mar 23 16:12:11 IST 2021
             {'id': 1100, 'format': '%a %b %d %H:%M:%S %Y %z', 'locale': None}, # git date output: Thu Mar 5 09:17:40 2020 -0800
             {'id': 1300, 'format': '%Y-%m-%dT%H:%M:%S.%f%Z', 'locale': None}, # ISO Format with UTC (found in syslog 5424): 2003-10-11T22:14:15.003Z
@@ -384,6 +406,9 @@ class timestamp:
             {'id': 1700, 'format': '%m/%d/%Y, %I:%M:%S %p', 'locale': None},  # Windows english format wint non-UTC tz (found in systeminfo cli output): 3/22/2021, 1:15:51 PM (UTC-0600)
             {'id': 1705, 'format': '%m/%d/%Y, %I:%M:%S %p %Z', 'locale': None},  # Windows english format with UTC tz (found in systeminfo cli output): 3/22/2021, 1:15:51 PM (UTC)
             {'id': 1710, 'format': '%m/%d/%Y, %I:%M:%S %p UTC%z', 'locale': None},  # Windows english format with UTC tz (found in systeminfo cli output): 3/22/2021, 1:15:51 PM (UTC+0000)
+            {'id': 1750, 'format': '%Y/%m/%d-%H:%M:%S.%f', 'locale': None},  # Google Big Table format with no timezone: 1970/01/01-01:00:00.000000
+            {'id': 1755, 'format': '%Y/%m/%d-%H:%M:%S.%f%z', 'locale': None},  # Google Big Table format with timezone: 1970/01/01-01:00:00.000000+00:00
+            {'id': 1800, 'format': '%d/%b/%Y:%H:%M:%S %z', 'locale': None},  # Common Log Format: 10/Oct/2000:13:55:36 -0700
             {'id': 2000, 'format': '%a %d %b %Y %I:%M:%S %p %Z', 'locale': None},  # en_US.UTF-8 local format (found in upower cli output): Tue 23 Mar 2021 04:12:11 PM UTC
             {'id': 3000, 'format': '%a %d %b %Y %I:%M:%S %p', 'locale': None},  # en_US.UTF-8 local format with non-UTC tz (found in upower cli output): Tue 23 Mar 2021 04:12:11 PM IST
             {'id': 4000, 'format': '%A %d %B %Y %I:%M:%S %p %Z', 'locale': None},  # European-style local format (found in upower cli output): Tuesday 01 October 2019 12:50:41 PM UTC
@@ -405,7 +430,7 @@ class timestamp:
 
         # from https://www.timeanddate.com/time/zones/
         # only removed UTC timezone and added known non-UTC offsets
-        tz_abbr = {
+        tz_abbr: set[str] = {
             'A', 'ACDT', 'ACST', 'ACT', 'ACWST', 'ADT', 'AEDT', 'AEST', 'AET', 'AFT', 'AKDT',
             'AKST', 'ALMT', 'AMST', 'AMT', 'ANAST', 'ANAT', 'AQTT', 'ART', 'AST', 'AT', 'AWDT',
             'AWST', 'AZOST', 'AZOT', 'AZST', 'AZT', 'AoE', 'B', 'BNT', 'BOT', 'BRST', 'BRT', 'BST',
@@ -433,7 +458,7 @@ class timestamp:
             'UTC+1345', 'UTC+1400'
         }
 
-        offset_suffixes = (
+        offset_suffixes: tuple[str, ...] = (
             '-12:00', '-11:00', '-10:00', '-09:30', '-09:00',
             '-08:00', '-07:00', '-06:00', '-05:00', '-04:00', '-03:00', '-02:30',
             '-02:00', '-01:00', '+01:00', '+02:00', '+03:00', '+04:00', '+04:30',
@@ -442,19 +467,20 @@ class timestamp:
             '+13:45', '+14:00'
         )
 
-        data = dt_string or ''
-        normalized_datetime = ''
-        utc_tz = False
-        dt = None
-        dt_utc = None
-        timestamp_naive = None
-        timestamp_utc = None
-        timestamp_obj = {
+        data: str = dt_string or ''
+        normalized_datetime: str = ''
+        utc_tz: bool = False
+        dt: Optional[datetime] = None
+        dt_utc: Optional[datetime] = None
+        timestamp_naive: Optional[int] = None
+        timestamp_utc: Optional[int] = None
+        iso_string: Optional[str] = None
+        timestamp_obj: Dict[str, Any] = {
             'format': None,
             'timestamp_naive': None,
-            'timestamp_utc': None
+            'timestamp_utc': None,
+            'iso': None
         }
-        utc_tz = False
 
         # convert format_hint to a tuple so it is hashable (for lru_cache)
         if not format_hint:
@@ -473,12 +499,15 @@ class timestamp:
             if 'UTC+' in data or 'UTC-' in data:
                 utc_tz = bool('UTC+0000' in data or 'UTC-0000' in data)
 
-        elif '+0000' in data or '-0000' in data:
+        elif '+0000' in data \
+             or '-0000' in data \
+             or '+00:00' in data \
+             or '-00:00' in data:
             utc_tz = True
 
         # normalize the timezone by taking out any timezone reference, except UTC
         cleandata = data.replace('(', '').replace(')', '')
-        normalized_datetime_list = []
+        normalized_datetime_list: List[str] = []
         for term in cleandata.split():
             if term not in tz_abbr:
                 normalized_datetime_list.append(term)
@@ -496,7 +525,7 @@ class timestamp:
         normalized_datetime = p.sub(r'\g<1> ', normalized_datetime)
 
         # try format hints first, then fall back to brute-force method
-        hint_obj_list = []
+        hint_obj_list: List[TimeStampFormatType] = []
         for fmt_id in format_hint:
             for fmt in formats:
                 if fmt_id == fmt['id']:
@@ -509,8 +538,9 @@ class timestamp:
             try:
                 locale.setlocale(locale.LC_TIME, fmt['locale'])
                 dt = datetime.strptime(normalized_datetime, fmt['format'])
-                timestamp_naive = int(dt.replace(tzinfo=None).timestamp())
                 timestamp_obj['format'] = fmt['id']
+                timestamp_naive = int(dt.replace(tzinfo=None).timestamp())
+                iso_string = dt.replace(tzinfo=None).isoformat()
                 locale.setlocale(locale.LC_TIME, None)
                 break
             except Exception:
@@ -520,9 +550,11 @@ class timestamp:
         if dt and utc_tz:
             dt_utc = dt.replace(tzinfo=timezone.utc)
             timestamp_utc = int(dt_utc.timestamp())
+            iso_string = dt_utc.isoformat()
 
         if timestamp_naive:
             timestamp_obj['timestamp_naive'] = timestamp_naive
             timestamp_obj['timestamp_utc'] = timestamp_utc
+            timestamp_obj['iso'] = iso_string
 
         return timestamp_obj
